pub struct ZwpTabletPadRingV2 { /* private fields */ }Expand description
pad ring
A circular interaction area, such as the touch ring on the Wacom Intuos Pro series tablets.
Events on a ring are logically grouped by the zwp_tablet_pad_ring_v2.frame event.
See also the Event enum for this interface.
Implementations
Sourceimpl ZwpTabletPadRingV2
impl ZwpTabletPadRingV2
Sourcepub fn set_feedback(&self, description: String, serial: u32)
pub fn set_feedback(&self, description: String, serial: u32)
set compositor feedback
Request that the compositor use the provided feedback string associated with this ring. This request should be issued immediately after a zwp_tablet_pad_group_v2.mode_switch event from the corresponding group is received, or whenever the ring is mapped to a different action. See zwp_tablet_pad_group_v2.mode_switch for more details.
Clients are encouraged to provide context-aware descriptions for the actions associated with the ring; compositors may use this information to offer visual feedback about the button layout (eg. on-screen displays).
The provided string ‘description’ is a UTF-8 encoded string to be associated with this ring, and is considered user-visible; general internationalization rules apply.
The serial argument will be that of the last zwp_tablet_pad_group_v2.mode_switch event received for the group of this ring. Requests providing other serials than the most recent one will be ignored.